PAWpySeed: pawpyseed.core.momentum.MomentumMatrix Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | List of all members
pawpyseed.core.momentum.MomentumMatrix Class Reference
Inheritance diagram for pawpyseed.core.momentum.MomentumMatrix:
[legend]
Collaboration diagram for pawpyseed.core.momentum.MomentumMatrix:
[legend]

## Public Member Functions
def | __init__ (self, wf, encut=None)
def | momentum_grid (self)
def | get_momentum_matrix_elems (self, b1, k1, s1, b2, k2, s2)
def | get_reciprocal_fullfw (self, b, k, s)
def | g_from_wf (self, b1, k1, s1, b2, k2, s2, G)

## Constructor & Destructor Documentation

def pawpyseed.core.momentum.MomentumMatrix.__init__ | ( |  | self,
|  |  | wf,
|  |  | encut = `None`
| ) |  |

## Member Function Documentation

def pawpyseed.core.momentum.MomentumMatrix.g_from_wf | ( |  | self,
|  |  | b1,
|  |  | k1,
|  |  | s1,
|  |  | b2,
|  |  | k2,
|  |  | s2,
|  |  | G
| ) |  |

def pawpyseed.core.momentum.MomentumMatrix.get_momentum_matrix_elems | ( |  | self,
|  |  | b1,
|  |  | k1,
|  |  | s1,
|  |  | b2,
|  |  | k2,
|  |  | s2
| ) |  |

def pawpyseed.core.momentum.MomentumMatrix.get_reciprocal_fullfw | ( |  | self,
|  |  | b,
|  |  | k,
|  |  | s
| ) |  |

def pawpyseed.core.momentum.MomentumMatrix.momentum_grid | ( |  | self | ) |

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/momentum.py